@@ -45,11 +45,17 @@ from anyenv.download.functional import (
     post_json_sync,
 )
 from anyenv.download.exceptions import RequestError, ResponseError, HttpError
-from anyenv.calling import ThreadGroup, method_spawner, function_spawner
+from anyenv.calling import (
+    ThreadGroup,
+    method_spawner,
+    function_spawner,
+    MultiEventHandler,
+)
 from anyenv.package_install.functional import install, install_sync
 from anyenv.testing import open_in_playground
 from anyenv.json_tools import load_json, JsonLoadError, dump_json, JsonDumpError
 from anyenv.download.base import HttpBackend, HttpResponse, Session
+from anyenv.code_execution import get_environment
 
 __all__ = [
     "HttpBackend",
@@ -57,6 +63,7 @@ __all__ = [
     "HttpResponse",
     "JsonDumpError",
     "JsonLoadError",
+    "MultiEventHandler",
     "RequestError",
     "ResponseError",
     "Session",
@@ -72,6 +79,7 @@ __all__ = [
     "get_backend",
     "get_bytes",
     "get_bytes_sync",
+    "get_environment",
     "get_json",
     "get_json_sync",
     "get_sync",
