@@ -3,6 +3,7 @@
 from __future__ import annotations
 
 from anyenv.calling.threadgroup import ThreadGroup
+from anyenv.calling.multieventhandler import MultiEventHandler
 from anyenv.calling.async_executor import method_spawner, function_spawner
 
-__all__ = ["ThreadGroup", "function_spawner", "method_spawner"]
+__all__ = ["MultiEventHandler", "ThreadGroup", "function_spawner", "method_spawner"]
